#!/bin/bash

PATH=/bin
export PATH
prefix=/usr
bindir=${prefix}/bin
sbindir=${prefix}/sbin

Xconfig=/usr/X11R6/lib/X11 # obsolete base dir
etcXconfig=/etc/X11	   # new base dir

manifest=/etc/preremove/rxvt-unicode-X-manifest.lst
[ -f ${manifest} ] || (echo "Unable to find manifest file" && exit 0)

################################################################
# Move old X config directories 
################################################################
mkdir -p $etcXconfig # assure new base dir exists

# subdirs to move
subconfigs="app-defaults fs lbxproxy proxymngr rstart twm xdm xinit xsm xserver"
for dir in $subconfigs; do

    Xdir=$Xconfig/$dir       # obsolete subdir
    etcXdir=$etcXconfig/$dir # new subdir

    mkdir -p $etcXdir # assure new subdir exists

    # Move to new location if not already there
    if test ! -L $Xdir && test -d $Xdir; then
	tar -cf - -C $Xdir . | tar -xvpUf - -C $etcXdir && \
	rm -rf $Xdir
    fi

    ln -sf $etcXdir $Xconfig/ # assure compatibility link exists

    # Clean up bad links left from old/buggy scripts
    if test -L $Xdir/$dir; then
	rm -f $Xdir/$dir
    fi
done


################################################################
# Handle app-defaults
################################################################
while read f; do
    fSrc=/etc/defaults/${f}
    fDest=/${f}
    if [ ! -e ${fDest} -a ! -L ${fDest} ]; then
        /bin/echo "Using the default version of ${fDest} (${fSrc})"
        /bin/touch ${fDest}
        /bin/cp ${fSrc} ${fDest}
    else
        echo ${fDest} already exists, not overwriting.
    fi
done < ${manifest}


################################################################
# Shortcuts
################################################################
/usr/bin/mkdir -p "$(/usr/bin/cygpath -AP)/Cygwin"
/usr/bin/mkshortcut -AP -n "Cygwin/rxvt-unicode-xC" -d "Cygwin RXVT Unicode Client (X11)" \
        -w /usr/bin -i /usr/bin/cygicons-0.dll -j 9 \
        -a '-display 127.0.0.1:0.0 -ls -e /bin/bash --login' \
        /usr/bin/urxvtc-X.exe
/usr/bin/mkshortcut -AP -n "Cygwin/rxvt-unicode-xS" -d "Cygwin RXVT Unicode Standalone (X11)" \
        -w /usr/bin -i /usr/bin/cygicons-0.dll -j 6 \
        -a '-display 127.0.0.1:0.0 -ls -e /bin/bash --login' \
        /usr/bin/urxvt-X.exe



################################################################
# Alternatives (eventually to be used in conjunction with a
# Win32 GDI -- that is, non X -- version of rxvt-unicode).
################################################################
${sbindir}/update-alternatives \
        --install ${bindir}/urxvt   urxvt   ${bindir}/urxvt-X.exe   30 \
        --slave   ${bindir}/urxvtc  urxvtc  ${bindir}/urxvtc-X.exe \
        --slave   ${bindir}/urxvtd  urxvtd  ${bindir}/urxvtd-X.exe

